@@ -1,5 +1,5 @@
 # Copyright 2019 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,9 +19,9 @@ from testflows._core.cli.arg.handlers.report.srs_coverage import Handler as srs_
 from testflows._core.cli.arg.handlers.report.results import Handler as results_handler
 from testflows._core.cli.arg.handlers.report.compare.handler import Handler as compare_handler
 from testflows._core.cli.arg.handlers.report.coverage import Handler as coverage_handler
-from testflows._core.cli.arg.handlers.report.map.handler import Handler as map_handler
-from testflows._core.cli.arg.handlers.report.openmetrics import Handler as openmetrics_handler
+from testflows._core.cli.arg.handlers.report.metrics import Handler as metrics_handler
 from testflows._core.cli.arg.handlers.report.specification import Handler as specification_handler
+from testflows._core.cli.arg.handlers.report.tracebility import Handler as tracebility_handler
 
 class Handler(HandlerBase):
     @classmethod
@@ -35,8 +35,8 @@ class Handler(HandlerBase):
         report_commands.required = True
         results_handler.add_command(report_commands)
         specification_handler.add_command(report_commands)
-        compare_handler.add_command(report_commands)
-        openmetrics_handler.add_command(report_commands)
+        tracebility_handler.add_command(report_commands)
         coverage_handler.add_command(report_commands)
+        compare_handler.add_command(report_commands)
+        metrics_handler.add_command(report_commands)
         #srs_coverage_handler.add_command(report_commands)
-        map_handler.add_command(report_commands)
